@@ -39,6 +39,11 @@
 #include <string.h>		/* For size_t.t */
 #include <time.h>		/* For time_t. */
 
+# ifdef __cplusplus
+extern "C"
+{
+# endif
+
 /**
  * OATH_VERSION
  *
@@ -46,7 +51,7 @@
  * version number.  Used together with oath_check_version() to verify
  * header file and run-time library consistency.
  */
-#define OATH_VERSION "2.0.2"
+#define OATH_VERSION "2.2.0"
 
 /**
  * OATH_VERSION_NUMBER
@@ -56,7 +61,7 @@
  * this symbol will have the value 0x01020300.  The last two digits
  * are only used between public releases, and will otherwise be 00.
  */
-#define OATH_VERSION_NUMBER 0x02000200
+#define OATH_VERSION_NUMBER 0x02020000
 
 /**
  * oath_rc:
@@ -280,4 +285,8 @@ oath_authenticate_usersfile (const char *usersfile,
 			     const char *passwd,
 			     time_t * last_otp);
 
+# ifdef __cplusplus
+}
+# endif
+
 #endif /* OATH_H */
